@@ -15,11 +15,10 @@ import (
 )
 
 var (
-	author string
-	// cursorPadding int
-	// rPromptOffset int
-	bgColor     string
-	outputImage string
+	author            string
+	colorSettingsFile string
+	bgColor           string
+	outputImage       string
 )
 
 // imageCmd represents the image command
@@ -30,10 +29,9 @@ var imageCmd = &cobra.Command{
 
 You can tweak the output by using additional flags:
 
-- author: displays the author below the prompt
 - cursor-padding: the padding of the prompt cursor
 - rprompt-offset: the offset of the right prompt
-- background-color: the background color of the image
+- settings: JSON file with overrides
 
 Example usage:
 
@@ -45,9 +43,9 @@ Exports the config to an image file called myconfig.png in the current working d
 
 Exports the config to an image file ~/mytheme.png.
 
-> oh-my-posh config export image --config ~/myconfig.omp.json --author "John Doe"
+> oh-my-posh config export image --config ~/myconfig.omp.json --settings ~/.image.settings.json
 
-Exports the config to an image file using customized output options.`,
+Exports the config to an image file using customized output settings.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
 		cfg, _ := config.Load(configFlag, shell.GENERIC, false)
@@ -55,7 +53,7 @@ Exports the config to an image file using customized output options.`,
 		flags := &runtime.Flags{
 			Config:        cfg.Source,
 			Shell:         shell.GENERIC,
-			TerminalWidth: 150,
+			TerminalWidth: 120,
 		}
 
 		env := &runtime.Terminal{}
@@ -81,19 +79,35 @@ Exports the config to an image file using customized output options.`,
 			Env:    env,
 		}
 
+		settings, err := image.LoadSettings(colorSettingsFile)
+		if err != nil {
+			settings = &image.Settings{
+				Colors:          image.NewColors(),
+				Author:          author,
+				BackgroundColor: bgColor,
+			}
+		}
+
+		if settings.Colors == nil {
+			settings.Colors = image.NewColors()
+		}
+
+		if settings.Cursor == "" {
+			settings.Cursor = "_"
+		}
+
 		primaryPrompt := eng.Primary()
 
 		imageCreator := &image.Renderer{
 			AnsiString: primaryPrompt,
-			Author:     author,
-			BgColor:    bgColor,
+			Settings:   *settings,
 		}
 
 		if outputImage != "" {
 			imageCreator.Path = cleanOutputPath(outputImage)
 		}
 
-		err := imageCreator.Init(env)
+		err = imageCreator.Init(env)
 		if err != nil {
 			fmt.Print(err.Error())
 			return
@@ -110,5 +124,11 @@ func init() {
 	imageCmd.Flags().StringVar(&author, "author", "", "config author")
 	imageCmd.Flags().StringVar(&bgColor, "background-color", "", "image background color")
 	imageCmd.Flags().StringVarP(&outputImage, "output", "o", "", "image file (.png) to export to")
+	imageCmd.Flags().StringVar(&colorSettingsFile, "settings", "", "color settings file to override ANSI color codes and metadata")
+
+	// deprecated flags
+	_ = imageCmd.Flags().MarkHidden("author")
+	_ = imageCmd.Flags().MarkHidden("background-color")
+
 	exportCmd.AddCommand(imageCmd)
 }
