@@ -22,7 +22,7 @@ var (
 	toggleLong = strings.Join(append([]string{toggleHelpText}, toggleArgs...), "\n- ")
 )
 
-// getCmd represents the get command
+// enableCmd represents the enable command
 var enableCmd = &cobra.Command{
 	Use:       fmt.Sprintf(toggleUse, "enable"),
 	Short:     "Enable a feature",
@@ -43,17 +43,16 @@ func init() {
 }
 
 func toggleFeature(cmd *cobra.Command, feature string, enable bool) {
-	env := &runtime.Terminal{
-		CmdFlags: &runtime.Flags{
-			Shell:     shellName,
-			SaveCache: true,
-		},
+	flags := &runtime.Flags{
+		Shell:     shellName,
+		SaveCache: true,
 	}
 
-	env.Init()
+	env := &runtime.Terminal{}
+	env.Init(flags)
 	defer env.Close()
 
-	if len(feature) == 0 {
+	if feature == "" {
 		_ = cmd.Help()
 		return
 	}
